@@ -1,5 +1,6 @@
 import sys
 import os
+import io
 import shutil
 import string
 import tempfile
@@ -14,30 +15,18 @@ import setuptools.command.build_ext
 import pybind11
 
 @contextlib.contextmanager
-def stdchannel_redirected(stdchannel, dest_filename):
+def stdchannel_redirected(stdchannel):
     """
-    From:
-    http://marc-abramowitz.com/archives/2013/07/19/python-context-manager-for-redirected-stdout-and-stderr/
-    A context manager to temporarily redirect stdout or stderr
-
-    e.g.:
-
-    with stdchannel_redirected(sys.stderr, os.devnull):
-        if compiler.has_function('clock_gettime', libraries=['rt']):
-            libraries.append('rt')
+    Redirects stdout or stderr to a StringIO object. As of python 3.4, there is a
+    standard library contextmanager for this, but backwards compatibility!
     """
     try:
-        oldstdchannel = os.dup(stdchannel.fileno())
-        dest_file = open(dest_filename, 'w')
-        os.dup2(dest_file.fileno(), stdchannel.fileno())
-
-        yield
+        s = io.StringIO()
+        old = getattr(sys, stdchannel)
+        setattr(sys, stdchannel, s)
+        yield s
     finally:
-        if oldstdchannel is not None:
-            os.dup2(oldstdchannel, stdchannel.fileno())
-        if dest_file is not None:
-            dest_file.close()
-
+        setattr(sys, stdchannel, old)
 
 quiet = True
 should_force_rebuild = False
@@ -187,6 +176,13 @@ def build_plugin(full_module_name, filepath):
         with stdchannel_redirected(sys.stdout, os.devnull):
             with stdchannel_redirected(sys.stderr, os.devnull):
                 setuptools.setup(**setuptools_args)
+        # f = io.StringIO()
+        # with redirect_stdout(f):
+        #     with redirect_stderr(f):
+        #         try:
+        #             setuptools.setup(**setuptools_args)
+        #         except:
+        #             print(f)
     else:
         setuptools.setup(**setuptools_args)
 
